@@ -1,4 +1,4 @@
-// 12dec21 Software Lab. Alexander Burger
+// 29may22 Software Lab. Alexander Burger
 
 #include "pico.h"
 
@@ -124,6 +124,14 @@ void initReadline(void) {
    rl_basic_quote_characters = NULL;
 }
 
+char *gReadline(const char *prompt) {
+   int e = errno;
+   char *p = readline(prompt);
+
+   errno = e;
+   return p;
+}
+
 void rlHide(void) {
    if (rl_readline_state & RL_STATE_INITIALIZED  &&  !(rl_readline_state & RL_STATE_DONE)) {
       rl_clear_visible_line();
@@ -248,7 +256,8 @@ int32_t gErrno(void) {
 
 // Terminal
 int Tio;
-struct termios OrgTermio, *Termio;
+struct termios OrgTermio;
+struct termios *Termio;
 
 static void tcSet(struct termios *p) {
    while (tcsetattr(STDIN_FILENO, TCSADRAIN, p)  &&  errno == EINTR);
@@ -477,18 +486,18 @@ const int64_t JmpBufSize = sizeof(jmp_buf);
 jmp_buf QuitRst;
 
 // Lisp data access from C
-uint64_t name(uint64_t x) {
+any name(any x) {
    while (!num(x))
       x = cdr(x);
    return x;
 }
 
-uint64_t number(uint64_t x) {
-   uint64_t n = cnt(x)? x >> 4 : val(dig(x));
+any number(any x) {
+   any n = cnt(x)? x >> 4 : val(dig(x));
    return sign(x)? -n : n;
 }
 
-uint64_t length(uint64_t x) {
+any length(any x) {
    int n = 0;
 
    while (!atom(x))
@@ -496,7 +505,7 @@ uint64_t length(uint64_t x) {
    return (int32_t)n;
 }
 
-uint64_t box64(uint64_t x) {
+any box64(any x) {
    return x & 0xF000000000000000? boxNum(x) : x << 4 | 2;
 }
 
@@ -718,6 +727,10 @@ uint64_t ffiCall(ffi *p, uint64_t lst) {
    return rc;
 }
 
+void *arg(void *p) {
+   return p;
+}
+
 // Case mappings from the GNU Kaffe Project
 #define CHAR_UPPERCASE  1
 #define CHAR_LOWERCASE  2
